@@ -19,6 +19,13 @@
 #' for working with blobs that is much faster when working with directories.
 #' You should consider using this rather than the classic blob API where
 #' possible; see the examples below.
+#'
+#' `board_azure()` is powered by the AzureStor package, which is a suggested
+#' dependency of pins (not required for pins in general). If you run into errors
+#' when deploying content to a server like <https://www.shinyapps.io> or
+#' [Connect](https://posit.co/products/enterprise/connect/), add
+#' `library(AzureStor)` to your app or document for [automatic dependency
+#' discovery](https://docs.posit.co/connect/user/troubleshooting/#render-missing-r-package).
 #' @export
 #' @examples
 #' if (requireNamespace("AzureStor")) {
@@ -65,7 +72,8 @@ board_azure <- function(container, path = "", n_processes = 10, versioned = TRUE
     }
   }
 
-  new_board_v1("pins_board_azure",
+  new_board_v1(
+    "pins_board_azure",
     name = "azure",
     container = container,
     path = path,
@@ -76,17 +84,16 @@ board_azure <- function(container, path = "", n_processes = 10, versioned = TRUE
 }
 
 board_azure_test <- function(path, type = c("blob", "file", "dfs"), ...) {
-  skip_if_missing_envvars("board_azure()", "PINS_AZURE_SAS")
+  skip_if_missing_envvars("board_azure()", "PINS_AZURE_KEY")
 
   type <- arg_match(type)
-  acct_name <- Sys.getenv("PINS_AZURE_ACCOUNT", "pins")
-  acct_url <- sprintf("https://%s.%s.core.windows.net/test-data", acct_name, type)
+  acct_name <- Sys.getenv("PINS_AZURE_ACCOUNT")
+  acct_url <- sprintf("https://%s.%s.core.windows.net/pins-rstats-testing-ci",
+                      acct_name, type)
 
-  # - as of Dec 2021, a SAS generated by the Azure portal can't be used with ADLS2
-  # - use AzureStor to generate the SAS instead: see ?AzureStor::get_account_sas
   container <- AzureStor::storage_container(
     acct_url,
-    sas = Sys.getenv("PINS_AZURE_SAS")
+    key = Sys.getenv("PINS_AZURE_KEY")
   )
   board_azure(container, path = path, cache = tempfile(), n_processes = 2, ...)
 }
@@ -164,7 +171,8 @@ pin_store.pins_board_azure <- function(board, name, paths, metadata,
 
   # Upload metadata
   local_azure_progress(FALSE)
-  azure_upload_file(board,
+  azure_upload_file(
+    board,
     src = textConnection(yaml::as.yaml(metadata)),
     dest = fs::path(version_dir, "data.txt")
   )
@@ -193,48 +201,41 @@ board_deparse.pins_board_azure <- function(board, ...) {
   expr(board_azure(!!container, path = !!board$path))
 }
 
+#' @export
+write_board_manifest_yaml.pins_board_azure <- function(board, manifest, ...) {
+
+  paths <- AzureStor::list_storage_files(board$container, info = "name")
+
+  if (manifest_pin_yaml_filename %in% paths) {
+    AzureStor::delete_storage_file(
+      board$container,
+      manifest_pin_yaml_filename,
+      confirm = FALSE
+    )
+  }
+
+  temp_file <- withr::local_tempfile()
+  yaml::write_yaml(manifest, file = temp_file)
+  azure_upload_file(board, src = temp_file, dest = manifest_pin_yaml_filename)
+}
+
+#' @rdname required_pkgs.pins_board
+#' @export
+required_pkgs.pins_board_azure <- function(x, ...) {
+  ellipsis::check_dots_empty()
+  "AzureStor"
+}
 
 # Helpers -----------------------------------------------------------------
 
-# logic for deleting dirs has been ported to AzureStor 3.5.2 as of Oct 2021
-# TODO: use AzureStor::delete_storage_dir()
 azure_delete_dir <- function(board, dir) {
   dir <- azure_normalize_path(board, dir)
-
-  # need 3 different ways of deleting a non-empty dir
-  # - blob storage: delete all files in dir and subdirs
-  # - file storage: delete files/dirs in reverse order, using correct function for each
-  # - adlsgen2: deleting dir will delete contents automatically
-  if (inherits(board$container, "blob_container")) {
-    ls <- AzureStor::list_storage_files(board$container, dir, recursive = TRUE)
-    for (path in rev(ls$name)) {
-      AzureStor::delete_storage_file(board$container, path, confirm = FALSE)
-    }
-    try(AzureStor::delete_storage_file(board$container, dir, confirm = FALSE),
-        silent = TRUE)
-
-  } else if (inherits(board$container, "file_share")) {
-    ls <- AzureStor::list_storage_files(board$container, dir, recursive = TRUE)
-    for (i in rev(seq_len(nrow(ls)))) {
-      if (ls$isdir[i]) {
-        AzureStor::delete_storage_dir(board$container, ls$name[i], confirm = FALSE)
-      } else {
-        AzureStor::delete_storage_file(board$container, ls$name[i], confirm = FALSE)
-      }
-    }
-    if (dir != "/") {
-      AzureStor::delete_storage_dir(board$container, dir, confirm = FALSE)
-    }
-
-  } else if (inherits(board$container, "adls_filesystem")) {
-    if (dir != "/") {
-      AzureStor::delete_storage_dir(board$container, dir, confirm = FALSE,
-                                    recursive = TRUE)
-    }
-
-  } else {
-    abort("Unknown Azure storage container type")
-  }
+  AzureStor::delete_storage_dir(
+    board$container,
+    dir,
+    confirm = FALSE,
+    recursive = TRUE
+  )
 }
 
 azure_ls <- function(board, dir = "") {
@@ -243,36 +244,18 @@ azure_ls <- function(board, dir = "") {
   paths <- AzureStor::list_storage_files(
     board$container,
     dir = dir,
-    recursive = FALSE,
-    info = "name"
+    recursive = FALSE
   )
-  unique(fs::path_file(paths))
+  unique(fs::path_file(paths$name[paths$isdir] %||% character(0)))
 }
 
-# TODO: implement this in AzureStor
 azure_dir_exists <- function(board, path) {
-
-  # need 3 different ways of testing if a dir exists (!)
-  # - blob storage: test if file list is non-empty
-  # - file storage: test if trying to get file list throws error
-  # - adlsgen2: use storage_file_exists()
-  if (inherits(board$container, "blob_container")) {
-    length(azure_ls(board, path)) > 0
-
-  } else if (inherits(board$container, "file_share")) {
-    !inherits(try(azure_ls(board, path), silent = TRUE), "try-error")
-
-  } else if (inherits(board$container, "adls_filesystem")) {
-    path <- azure_normalize_path(board, path)
-    AzureStor::storage_file_exists(board$container, path)
-
-  } else {
-    abort("Unknown Azure storage container type")
-  }
+  dir <- azure_normalize_path(board, path)
+  AzureStor::storage_dir_exists(board$container, dir)
 }
 
 local_azure_progress <- function(progress = !is_testing(), env = parent.frame()) {
-  withr::local_options(azure_storage_progress_bar = progress, .local_envir = env)
+  withr::local_options(list(azure_storage_progress_bar = progress), .local_envir = env)
 }
 
 azure_download <- function(board, keys, progress = !is_testing()) {
