@@ -124,3 +124,11 @@ board_deparse.pins_board_folder <- function(board, ...) {
   path <- check_board_deparse(board, "path")
   expr(board_folder(path = !!as.character(path)))
 }
+
+#' @export
+write_board_manifest_yaml.pins_board_folder <- function(board, manifest, ...) {
+  yaml::write_yaml(
+    manifest,
+    file = fs::path(board$path, manifest_pin_yaml_filename)
+  )
+}
